/**
 * Groestl implementation.
 *
 * ==========================(LICENSE BEGIN)============================
 *
 * Copyright (c) 2007-2010  Projet RNRT SAPHIR
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * ===========================(LICENSE END)=============================
 *
 * @file     groest_tables_c.h
 * @author   Wolfgang Wieser <w.wieser@student.tugraz.at>
 *
 * This code is based on works of Thomas Pornin and Projet RNRT SAPHIR
 * and was adapted to tweaks of GROESTL for third round of SHA-3 competition.
 * It is part of a collection of header files, which implements GROESTL's
 * functions in C and assembler, optimized for 32-Bit ARM processors.
 */

//#############################################################################
//###########  LOOKUP TABLES FOR GROESTL ######################################
//#############################################################################
 
#define DEFINE_TABLES {                   \
       asm volatile (                     \
          "\n b TABLE_END                "\
          "\n T0up:                      "\
          "\n     .word    0xA5F432C6    "\
          "\n     .word    0x84976FF8    "\
          "\n     .word    0x99B05EEE    "\
          "\n     .word    0x8D8C7AF6    "\
          "\n     .word    0x0D17E8FF    "\
          "\n     .word    0xBDDC0AD6    "\
          "\n     .word    0xB1C816DE    "\
          "\n     .word    0x54FC6D91    "\
          "\n     .word    0x50F09060    "\
          "\n     .word    0x03050702    "\
          "\n     .word    0xA9E02ECE    "\
          "\n     .word    0x7D87D156    "\
          "\n     .word    0x192BCCE7    "\
          "\n     .word    0x62A613B5    "\
          "\n     .word    0xE6317C4D    "\
          "\n     .word    0x9AB559EC    "\
          "\n     .word    0x45CF408F    "\
          "\n     .word    0x9DBCA31F    "\
          "\n     .word    0x40C04989    "\
          "\n     .word    0x879268FA    "\
          "\n     .word    0x153FD0EF    "\
          "\n     .word    0xEB2694B2    "\
          "\n     .word    0xC940CE8E    "\
          "\n     .word    0x0B1DE6FB    "\
          "\n     .word    0xEC2F6E41    "\
          "\n     .word    0x67A91AB3    "\
          "\n     .word    0xFD1C435F    "\
          "\n     .word    0xEA256045    "\
          "\n     .word    0xBFDAF923    "\
          "\n     .word    0xF7025153    "\
          "\n     .word    0x96A145E4    "\
          "\n     .word    0x5BED769B    "\
          "\n     .word    0xC25D2875    "\
          "\n     .word    0x1C24C5E1    "\
          "\n     .word    0xAEE9D43D    "\
          "\n     .word    0x6ABEF24C    "\
          "\n     .word    0x5AEE826C    "\
          "\n     .word    0x41C3BD7E    "\
          "\n     .word    0x0206F3F5    "\
          "\n     .word    0x4FD15283    "\
          "\n     .word    0x5CE48C68    "\
          "\n     .word    0xF4075651    "\
          "\n     .word    0x345C8DD1    "\
          "\n     .word    0x0818E1F9    "\
          "\n     .word    0x93AE4CE2    "\
          "\n     .word    0x73953EAB    "\
          "\n     .word    0x53F59762    "\
          "\n     .word    0x3F416B2A    "\
          "\n     .word    0x0C141C08    "\
          "\n     .word    0x52F66395    "\
          "\n     .word    0x65AFE946    "\
          "\n     .word    0x5EE27F9D    "\
          "\n     .word    0x28784830    "\
          "\n     .word    0xA1F8CF37    "\
          "\n     .word    0x0F111B0A    "\
          "\n     .word    0xB5C4EB2F    "\
          "\n     .word    0x091B150E    "\
          "\n     .word    0x365A7E24    "\
          "\n     .word    0x9BB6AD1B    "\
          "\n     .word    0x3D4798DF    "\
          "\n     .word    0x266AA7CD    "\
          "\n     .word    0x69BBF54E    "\
          "\n     .word    0xCD4C337F    "\
          "\n     .word    0x9FBA50EA    "\
          "\n     .word    0x1B2D3F12    "\
          "\n     .word    0x9EB9A41D    "\
          "\n     .word    0x749CC458    "\
          "\n     .word    0x2E724634    "\
          "\n     .word    0x2D774136    "\
          "\n     .word    0xB2CD11DC    "\
          "\n     .word    0xEE299DB4    "\
          "\n     .word    0xFB164D5B    "\
          "\n     .word    0xF601A5A4    "\
          "\n     .word    0x4DD7A176    "\
          "\n     .word    0x61A314B7    "\
          "\n     .word    0xCE49347D    "\
          "\n     .word    0x7B8DDF52    "\
          "\n     .word    0x3E429FDD    "\
          "\n     .word    0x7193CD5E    "\
          "\n     .word    0x97A2B113    "\
          "\n     .word    0xF504A2A6    "\
          "\n     .word    0x68B801B9    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0x2C74B5C1    "\
          "\n     .word    0x60A0E040    "\
          "\n     .word    0x1F21C2E3    "\
          "\n     .word    0xC8433A79    "\
          "\n     .word    0xED2C9AB6    "\
          "\n     .word    0xBED90DD4    "\
          "\n     .word    0x46CA478D    "\
          "\n     .word    0xD9701767    "\
          "\n     .word    0x4BDDAF72    "\
          "\n     .word    0xDE79ED94    "\
          "\n     .word    0xD467FF98    "\
          "\n     .word    0xE82393B0    "\
          "\n     .word    0x4ADE5B85    "\
          "\n     .word    0x6BBD06BB    "\
          "\n     .word    0x2A7EBBC5    "\
          "\n     .word    0xE5347B4F    "\
          "\n     .word    0x163AD7ED    "\
          "\n     .word    0xC554D286    "\
          "\n     .word    0xD762F89A    "\
          "\n     .word    0x55FF9966    "\
          "\n     .word    0x94A7B611    "\
          "\n     .word    0xCF4AC08A    "\
          "\n     .word    0x1030D9E9    "\
          "\n     .word    0x060A0E04    "\
          "\n     .word    0x819866FE    "\
          "\n     .word    0xF00BABA0    "\
          "\n     .word    0x44CCB478    "\
          "\n     .word    0xBAD5F025    "\
          "\n     .word    0xE33E754B    "\
          "\n     .word    0xF30EACA2    "\
          "\n     .word    0xFE19445D    "\
          "\n     .word    0xC05BDB80    "\
          "\n     .word    0x8A858005    "\
          "\n     .word    0xADECD33F    "\
          "\n     .word    0xBCDFFE21    "\
          "\n     .word    0x48D8A870    "\
          "\n     .word    0x040CFDF1    "\
          "\n     .word    0xDF7A1963    "\
          "\n     .word    0xC1582F77    "\
          "\n     .word    0x759F30AF    "\
          "\n     .word    0x63A5E742    "\
          "\n     .word    0x30507020    "\
          "\n     .word    0x1A2ECBE5    "\
          "\n     .word    0x0E12EFFD    "\
          "\n     .word    0x6DB708BF    "\
          "\n     .word    0x4CD45581    "\
          "\n     .word    0x143C2418    "\
          "\n     .word    0x355F7926    "\
          "\n     .word    0x2F71B2C3    "\
          "\n     .word    0xE13886BE    "\
          "\n     .word    0xA2FDC835    "\
          "\n     .word    0xCC4FC788    "\
          "\n     .word    0x394B652E    "\
          "\n     .word    0x57F96A93    "\
          "\n     .word    0xF20D5855    "\
          "\n     .word    0x829D61FC    "\
          "\n     .word    0x47C9B37A    "\
          "\n     .word    0xACEF27C8    "\
          "\n     .word    0xE73288BA    "\
          "\n     .word    0x2B7D4F32    "\
          "\n     .word    0x95A442E6    "\
          "\n     .word    0xA0FB3BC0    "\
          "\n     .word    0x98B3AA19    "\
          "\n     .word    0xD168F69E    "\
          "\n     .word    0x7F8122A3    "\
          "\n     .word    0x66AAEE44    "\
          "\n     .word    0x7E82D654    "\
          "\n     .word    0xABE6DD3B    "\
          "\n     .word    0x839E950B    "\
          "\n     .word    0xCA45C98C    "\
          "\n     .word    0x297BBCC7    "\
          "\n     .word    0xD36E056B    "\
          "\n     .word    0x3C446C28    "\
          "\n     .word    0x798B2CA7    "\
          "\n     .word    0xE23D81BC    "\
          "\n     .word    0x1D273116    "\
          "\n     .word    0x769A37AD    "\
          "\n     .word    0x3B4D96DB    "\
          "\n     .word    0x56FA9E64    "\
          "\n     .word    0x4ED2A674    "\
          "\n     .word    0x1E223614    "\
          "\n     .word    0xDB76E492    "\
          "\n     .word    0x0A1E120C    "\
          "\n     .word    0x6CB4FC48    "\
          "\n     .word    0xE4378FB8    "\
          "\n     .word    0x5DE7789F    "\
          "\n     .word    0x6EB20FBD    "\
          "\n     .word    0xEF2A6943    "\
          "\n     .word    0xA6F135C4    "\
          "\n     .word    0xA8E3DA39    "\
          "\n     .word    0xA4F7C631    "\
          "\n     .word    0x37598AD3    "\
          "\n     .word    0x8B8674F2    "\
          "\n     .word    0x325683D5    "\
          "\n     .word    0x43C54E8B    "\
          "\n     .word    0x59EB856E    "\
          "\n     .word    0xB7C218DA    "\
          "\n     .word    0x8C8F8E01    "\
          "\n     .word    0x64AC1DB1    "\
          "\n     .word    0xD26DF19C    "\
          "\n     .word    0xE03B7249    "\
          "\n     .word    0xB4C71FD8    "\
          "\n     .word    0xFA15B9AC    "\
          "\n     .word    0x0709FAF3    "\
          "\n     .word    0x256FA0CF    "\
          "\n     .word    0xAFEA20CA    "\
          "\n     .word    0x8E897DF4    "\
          "\n     .word    0xE9206747    "\
          "\n     .word    0x18283810    "\
          "\n     .word    0xD5640B6F    "\
          "\n     .word    0x888373F0    "\
          "\n     .word    0x6FB1FB4A    "\
          "\n     .word    0x7296CA5C    "\
          "\n     .word    0x246C5438    "\
          "\n     .word    0xF1085F57    "\
          "\n     .word    0xC7522173    "\
          "\n     .word    0x51F36497    "\
          "\n     .word    0x2365AECB    "\
          "\n     .word    0x7C8425A1    "\
          "\n     .word    0x9CBF57E8    "\
          "\n     .word    0x21635D3E    "\
          "\n     .word    0xDD7CEA96    "\
          "\n     .word    0xDC7F1E61    "\
          "\n     .word    0x86919C0D    "\
          "\n     .word    0x85949B0F    "\
          "\n     .word    0x90AB4BE0    "\
          "\n     .word    0x42C6BA7C    "\
          "\n     .word    0xC4572671    "\
          "\n     .word    0xAAE529CC    "\
          "\n     .word    0xD873E390    "\
          "\n     .word    0x050F0906    "\
          "\n     .word    0x0103F4F7    "\
          "\n     .word    0x12362A1C    "\
          "\n     .word    0xA3FE3CC2    "\
          "\n     .word    0x5FE18B6A    "\
          "\n     .word    0xF910BEAE    "\
          "\n     .word    0xD06B0269    "\
          "\n     .word    0x91A8BF17    "\
          "\n     .word    0x58E87199    "\
          "\n     .word    0x2769533A    "\
          "\n     .word    0xB9D0F727    "\
          "\n     .word    0x384891D9    "\
          "\n     .word    0x1335DEEB    "\
          "\n     .word    0xB3CEE52B    "\
          "\n     .word    0x33557722    "\
          "\n     .word    0xBBD604D2    "\
          "\n     .word    0x709039A9    "\
          "\n     .word    0x89808707    "\
          "\n     .word    0xA7F2C133    "\
          "\n     .word    0xB6C1EC2D    "\
          "\n     .word    0x22665A3C    "\
          "\n     .word    0x92ADB815    "\
          "\n     .word    0x2060A9C9    "\
          "\n     .word    0x49DB5C87    "\
          "\n     .word    0xFF1AB0AA    "\
          "\n     .word    0x7888D850    "\
          "\n     .word    0x7A8E2BA5    "\
          "\n     .word    0x8F8A8903    "\
          "\n     .word    0xF8134A59    "\
          "\n     .word    0x809B9209    "\
          "\n     .word    0x1739231A    "\
          "\n     .word    0xDA751065    "\
          "\n     .word    0x315384D7    "\
          "\n     .word    0xC651D584    "\
          "\n     .word    0xB8D303D0    "\
          "\n     .word    0xC35EDC82    "\
          "\n     .word    0xB0CBE229    "\
          "\n     .word    0x7799C35A    "\
          "\n     .word    0x11332D1E    "\
          "\n     .word    0xCB463D7B    "\
          "\n     .word    0xFC1FB7A8    "\
          "\n     .word    0xD6610C6D    "\
          "\n     .word    0x3A4E622C    "\
          "\n T0dn:                      "\
          "\n     .word    0xC6A597F4    "\
          "\n     .word    0xF884EB97    "\
          "\n     .word    0xEE99C7B0    "\
          "\n     .word    0xF68DF78C    "\
          "\n     .word    0xFF0DE517    "\
          "\n     .word    0xD6BDB7DC    "\
          "\n     .word    0xDEB1A7C8    "\
          "\n     .word    0x915439FC    "\
          "\n     .word    0x6050C0F0    "\
          "\n     .word    0x02030405    "\
          "\n     .word    0xCEA987E0    "\
          "\n     .word    0x567DAC87    "\
          "\n     .word    0xE719D52B    "\
          "\n     .word    0xB56271A6    "\
          "\n     .word    0x4DE69A31    "\
          "\n     .word    0xEC9AC3B5    "\
          "\n     .word    0x8F4505CF    "\
          "\n     .word    0x1F9D3EBC    "\
          "\n     .word    0x894009C0    "\
          "\n     .word    0xFA87EF92    "\
          "\n     .word    0xEF15C53F    "\
          "\n     .word    0xB2EB7F26    "\
          "\n     .word    0x8EC90740    "\
          "\n     .word    0xFB0BED1D    "\
          "\n     .word    0x41EC822F    "\
          "\n     .word    0xB3677DA9    "\
          "\n     .word    0x5FFDBE1C    "\
          "\n     .word    0x45EA8A25    "\
          "\n     .word    0x23BF46DA    "\
          "\n     .word    0x53F7A602    "\
          "\n     .word    0xE496D3A1    "\
          "\n     .word    0x9B5B2DED    "\
          "\n     .word    0x75C2EA5D    "\
          "\n     .word    0xE11CD924    "\
          "\n     .word    0x3DAE7AE9    "\
          "\n     .word    0x4C6A98BE    "\
          "\n     .word    0x6C5AD8EE    "\
          "\n     .word    0x7E41FCC3    "\
          "\n     .word    0xF502F106    "\
          "\n     .word    0x834F1DD1    "\
          "\n     .word    0x685CD0E4    "\
          "\n     .word    0x51F4A207    "\
          "\n     .word    0xD134B95C    "\
          "\n     .word    0xF908E918    "\
          "\n     .word    0xE293DFAE    "\
          "\n     .word    0xAB734D95    "\
          "\n     .word    0x6253C4F5    "\
          "\n     .word    0x2A3F5441    "\
          "\n     .word    0x080C1014    "\
          "\n     .word    0x955231F6    "\
          "\n     .word    0x46658CAF    "\
          "\n     .word    0x9D5E21E2    "\
          "\n     .word    0x30286078    "\
          "\n     .word    0x37A16EF8    "\
          "\n     .word    0x0A0F1411    "\
          "\n     .word    0x2FB55EC4    "\
          "\n     .word    0x0E091C1B    "\
          "\n     .word    0x2436485A    "\
          "\n     .word    0x1B9B36B6    "\
          "\n     .word    0xDF3DA547    "\
          "\n     .word    0xCD26816A    "\
          "\n     .word    0x4E699CBB    "\
          "\n     .word    0x7FCDFE4C    "\
          "\n     .word    0xEA9FCFBA    "\
          "\n     .word    0x121B242D    "\
          "\n     .word    0x1D9E3AB9    "\
          "\n     .word    0x5874B09C    "\
          "\n     .word    0x342E6872    "\
          "\n     .word    0x362D6C77    "\
          "\n     .word    0xDCB2A3CD    "\
          "\n     .word    0xB4EE7329    "\
          "\n     .word    0x5BFBB616    "\
          "\n     .word    0xA4F65301    "\
          "\n     .word    0x764DECD7    "\
          "\n     .word    0xB76175A3    "\
          "\n     .word    0x7DCEFA49    "\
          "\n     .word    0x527BA48D    "\
          "\n     .word    0xDD3EA142    "\
          "\n     .word    0x5E71BC93    "\
          "\n     .word    0x139726A2    "\
          "\n     .word    0xA6F55704    "\
          "\n     .word    0xB96869B8    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0xC12C9974    "\
          "\n     .word    0x406080A0    "\
          "\n     .word    0xE31FDD21    "\
          "\n     .word    0x79C8F243    "\
          "\n     .word    0xB6ED772C    "\
          "\n     .word    0xD4BEB3D9    "\
          "\n     .word    0x8D4601CA    "\
          "\n     .word    0x67D9CE70    "\
          "\n     .word    0x724BE4DD    "\
          "\n     .word    0x94DE3379    "\
          "\n     .word    0x98D42B67    "\
          "\n     .word    0xB0E87B23    "\
          "\n     .word    0x854A11DE    "\
          "\n     .word    0xBB6B6DBD    "\
          "\n     .word    0xC52A917E    "\
          "\n     .word    0x4FE59E34    "\
          "\n     .word    0xED16C13A    "\
          "\n     .word    0x86C51754    "\
          "\n     .word    0x9AD72F62    "\
          "\n     .word    0x6655CCFF    "\
          "\n     .word    0x119422A7    "\
          "\n     .word    0x8ACF0F4A    "\
          "\n     .word    0xE910C930    "\
          "\n     .word    0x0406080A    "\
          "\n     .word    0xFE81E798    "\
          "\n     .word    0xA0F05B0B    "\
          "\n     .word    0x7844F0CC    "\
          "\n     .word    0x25BA4AD5    "\
          "\n     .word    0x4BE3963E    "\
          "\n     .word    0xA2F35F0E    "\
          "\n     .word    0x5DFEBA19    "\
          "\n     .word    0x80C01B5B    "\
          "\n     .word    0x058A0A85    "\
          "\n     .word    0x3FAD7EEC    "\
          "\n     .word    0x21BC42DF    "\
          "\n     .word    0x7048E0D8    "\
          "\n     .word    0xF104F90C    "\
          "\n     .word    0x63DFC67A    "\
          "\n     .word    0x77C1EE58    "\
          "\n     .word    0xAF75459F    "\
          "\n     .word    0x426384A5    "\
          "\n     .word    0x20304050    "\
          "\n     .word    0xE51AD12E    "\
          "\n     .word    0xFD0EE112    "\
          "\n     .word    0xBF6D65B7    "\
          "\n     .word    0x814C19D4    "\
          "\n     .word    0x1814303C    "\
          "\n     .word    0x26354C5F    "\
          "\n     .word    0xC32F9D71    "\
          "\n     .word    0xBEE16738    "\
          "\n     .word    0x35A26AFD    "\
          "\n     .word    0x88CC0B4F    "\
          "\n     .word    0x2E395C4B    "\
          "\n     .word    0x93573DF9    "\
          "\n     .word    0x55F2AA0D    "\
          "\n     .word    0xFC82E39D    "\
          "\n     .word    0x7A47F4C9    "\
          "\n     .word    0xC8AC8BEF    "\
          "\n     .word    0xBAE76F32    "\
          "\n     .word    0x322B647D    "\
          "\n     .word    0xE695D7A4    "\
          "\n     .word    0xC0A09BFB    "\
          "\n     .word    0x199832B3    "\
          "\n     .word    0x9ED12768    "\
          "\n     .word    0xA37F5D81    "\
          "\n     .word    0x446688AA    "\
          "\n     .word    0x547EA882    "\
          "\n     .word    0x3BAB76E6    "\
          "\n     .word    0x0B83169E    "\
          "\n     .word    0x8CCA0345    "\
          "\n     .word    0xC729957B    "\
          "\n     .word    0x6BD3D66E    "\
          "\n     .word    0x283C5044    "\
          "\n     .word    0xA779558B    "\
          "\n     .word    0xBCE2633D    "\
          "\n     .word    0x161D2C27    "\
          "\n     .word    0xAD76419A    "\
          "\n     .word    0xDB3BAD4D    "\
          "\n     .word    0x6456C8FA    "\
          "\n     .word    0x744EE8D2    "\
          "\n     .word    0x141E2822    "\
          "\n     .word    0x92DB3F76    "\
          "\n     .word    0x0C0A181E    "\
          "\n     .word    0x486C90B4    "\
          "\n     .word    0xB8E46B37    "\
          "\n     .word    0x9F5D25E7    "\
          "\n     .word    0xBD6E61B2    "\
          "\n     .word    0x43EF862A    "\
          "\n     .word    0xC4A693F1    "\
          "\n     .word    0x39A872E3    "\
          "\n     .word    0x31A462F7    "\
          "\n     .word    0xD337BD59    "\
          "\n     .word    0xF28BFF86    "\
          "\n     .word    0xD532B156    "\
          "\n     .word    0x8B430DC5    "\
          "\n     .word    0x6E59DCEB    "\
          "\n     .word    0xDAB7AFC2    "\
          "\n     .word    0x018C028F    "\
          "\n     .word    0xB16479AC    "\
          "\n     .word    0x9CD2236D    "\
          "\n     .word    0x49E0923B    "\
          "\n     .word    0xD8B4ABC7    "\
          "\n     .word    0xACFA4315    "\
          "\n     .word    0xF307FD09    "\
          "\n     .word    0xCF25856F    "\
          "\n     .word    0xCAAF8FEA    "\
          "\n     .word    0xF48EF389    "\
          "\n     .word    0x47E98E20    "\
          "\n     .word    0x10182028    "\
          "\n     .word    0x6FD5DE64    "\
          "\n     .word    0xF088FB83    "\
          "\n     .word    0x4A6F94B1    "\
          "\n     .word    0x5C72B896    "\
          "\n     .word    0x3824706C    "\
          "\n     .word    0x57F1AE08    "\
          "\n     .word    0x73C7E652    "\
          "\n     .word    0x975135F3    "\
          "\n     .word    0xCB238D65    "\
          "\n     .word    0xA17C5984    "\
          "\n     .word    0xE89CCBBF    "\
          "\n     .word    0x3E217C63    "\
          "\n     .word    0x96DD377C    "\
          "\n     .word    0x61DCC27F    "\
          "\n     .word    0x0D861A91    "\
          "\n     .word    0x0F851E94    "\
          "\n     .word    0xE090DBAB    "\
          "\n     .word    0x7C42F8C6    "\
          "\n     .word    0x71C4E257    "\
          "\n     .word    0xCCAA83E5    "\
          "\n     .word    0x90D83B73    "\
          "\n     .word    0x06050C0F    "\
          "\n     .word    0xF701F503    "\
          "\n     .word    0x1C123836    "\
          "\n     .word    0xC2A39FFE    "\
          "\n     .word    0x6A5FD4E1    "\
          "\n     .word    0xAEF94710    "\
          "\n     .word    0x69D0D26B    "\
          "\n     .word    0x17912EA8    "\
          "\n     .word    0x995829E8    "\
          "\n     .word    0x3A277469    "\
          "\n     .word    0x27B94ED0    "\
          "\n     .word    0xD938A948    "\
          "\n     .word    0xEB13CD35    "\
          "\n     .word    0x2BB356CE    "\
          "\n     .word    0x22334455    "\
          "\n     .word    0xD2BBBFD6    "\
          "\n     .word    0xA9704990    "\
          "\n     .word    0x07890E80    "\
          "\n     .word    0x33A766F2    "\
          "\n     .word    0x2DB65AC1    "\
          "\n     .word    0x3C227866    "\
          "\n     .word    0x15922AAD    "\
          "\n     .word    0xC9208960    "\
          "\n     .word    0x874915DB    "\
          "\n     .word    0xAAFF4F1A    "\
          "\n     .word    0x5078A088    "\
          "\n     .word    0xA57A518E    "\
          "\n     .word    0x038F068A    "\
          "\n     .word    0x59F8B213    "\
          "\n     .word    0x0980129B    "\
          "\n     .word    0x1A173439    "\
          "\n     .word    0x65DACA75    "\
          "\n     .word    0xD731B553    "\
          "\n     .word    0x84C61351    "\
          "\n     .word    0xD0B8BBD3    "\
          "\n     .word    0x82C31F5E    "\
          "\n     .word    0x29B052CB    "\
          "\n     .word    0x5A77B499    "\
          "\n     .word    0x1E113C33    "\
          "\n     .word    0x7BCBF646    "\
          "\n     .word    0xA8FC4B1F    "\
          "\n     .word    0x6DD6DA61    "\
          "\n     .word    0x2C3A584E    "\
          "\n T1up:                      "\
          "\n     .word    0xF432C6C6    "\
          "\n     .word    0x976FF8F8    "\
          "\n     .word    0xB05EEEEE    "\
          "\n     .word    0x8C7AF6F6    "\
          "\n     .word    0x17E8FFFF    "\
          "\n     .word    0xDC0AD6D6    "\
          "\n     .word    0xC816DEDE    "\
          "\n     .word    0xFC6D9191    "\
          "\n     .word    0xF0906060    "\
          "\n     .word    0x05070202    "\
          "\n     .word    0xE02ECECE    "\
          "\n     .word    0x87D15656    "\
          "\n     .word    0x2BCCE7E7    "\
          "\n     .word    0xA613B5B5    "\
          "\n     .word    0x317C4D4D    "\
          "\n     .word    0xB559ECEC    "\
          "\n     .word    0xCF408F8F    "\
          "\n     .word    0xBCA31F1F    "\
          "\n     .word    0xC0498989    "\
          "\n     .word    0x9268FAFA    "\
          "\n     .word    0x3FD0EFEF    "\
          "\n     .word    0x2694B2B2    "\
          "\n     .word    0x40CE8E8E    "\
          "\n     .word    0x1DE6FBFB    "\
          "\n     .word    0x2F6E4141    "\
          "\n     .word    0xA91AB3B3    "\
          "\n     .word    0x1C435F5F    "\
          "\n     .word    0x25604545    "\
          "\n     .word    0xDAF92323    "\
          "\n     .word    0x02515353    "\
          "\n     .word    0xA145E4E4    "\
          "\n     .word    0xED769B9B    "\
          "\n     .word    0x5D287575    "\
          "\n     .word    0x24C5E1E1    "\
          "\n     .word    0xE9D43D3D    "\
          "\n     .word    0xBEF24C4C    "\
          "\n     .word    0xEE826C6C    "\
          "\n     .word    0xC3BD7E7E    "\
          "\n     .word    0x06F3F5F5    "\
          "\n     .word    0xD1528383    "\
          "\n     .word    0xE48C6868    "\
          "\n     .word    0x07565151    "\
          "\n     .word    0x5C8DD1D1    "\
          "\n     .word    0x18E1F9F9    "\
          "\n     .word    0xAE4CE2E2    "\
          "\n     .word    0x953EABAB    "\
          "\n     .word    0xF5976262    "\
          "\n     .word    0x416B2A2A    "\
          "\n     .word    0x141C0808    "\
          "\n     .word    0xF6639595    "\
          "\n     .word    0xAFE94646    "\
          "\n     .word    0xE27F9D9D    "\
          "\n     .word    0x78483030    "\
          "\n     .word    0xF8CF3737    "\
          "\n     .word    0x111B0A0A    "\
          "\n     .word    0xC4EB2F2F    "\
          "\n     .word    0x1B150E0E    "\
          "\n     .word    0x5A7E2424    "\
          "\n     .word    0xB6AD1B1B    "\
          "\n     .word    0x4798DFDF    "\
          "\n     .word    0x6AA7CDCD    "\
          "\n     .word    0xBBF54E4E    "\
          "\n     .word    0x4C337F7F    "\
          "\n     .word    0xBA50EAEA    "\
          "\n     .word    0x2D3F1212    "\
          "\n     .word    0xB9A41D1D    "\
          "\n     .word    0x9CC45858    "\
          "\n     .word    0x72463434    "\
          "\n     .word    0x77413636    "\
          "\n     .word    0xCD11DCDC    "\
          "\n     .word    0x299DB4B4    "\
          "\n     .word    0x164D5B5B    "\
          "\n     .word    0x01A5A4A4    "\
          "\n     .word    0xD7A17676    "\
          "\n     .word    0xA314B7B7    "\
          "\n     .word    0x49347D7D    "\
          "\n     .word    0x8DDF5252    "\
          "\n     .word    0x429FDDDD    "\
          "\n     .word    0x93CD5E5E    "\
          "\n     .word    0xA2B11313    "\
          "\n     .word    0x04A2A6A6    "\
          "\n     .word    0xB801B9B9    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0x74B5C1C1    "\
          "\n     .word    0xA0E04040    "\
          "\n     .word    0x21C2E3E3    "\
          "\n     .word    0x433A7979    "\
          "\n     .word    0x2C9AB6B6    "\
          "\n     .word    0xD90DD4D4    "\
          "\n     .word    0xCA478D8D    "\
          "\n     .word    0x70176767    "\
          "\n     .word    0xDDAF7272    "\
          "\n     .word    0x79ED9494    "\
          "\n     .word    0x67FF9898    "\
          "\n     .word    0x2393B0B0    "\
          "\n     .word    0xDE5B8585    "\
          "\n     .word    0xBD06BBBB    "\
          "\n     .word    0x7EBBC5C5    "\
          "\n     .word    0x347B4F4F    "\
          "\n     .word    0x3AD7EDED    "\
          "\n     .word    0x54D28686    "\
          "\n     .word    0x62F89A9A    "\
          "\n     .word    0xFF996666    "\
          "\n     .word    0xA7B61111    "\
          "\n     .word    0x4AC08A8A    "\
          "\n     .word    0x30D9E9E9    "\
          "\n     .word    0x0A0E0404    "\
          "\n     .word    0x9866FEFE    "\
          "\n     .word    0x0BABA0A0    "\
          "\n     .word    0xCCB47878    "\
          "\n     .word    0xD5F02525    "\
          "\n     .word    0x3E754B4B    "\
          "\n     .word    0x0EACA2A2    "\
          "\n     .word    0x19445D5D    "\
          "\n     .word    0x5BDB8080    "\
          "\n     .word    0x85800505    "\
          "\n     .word    0xECD33F3F    "\
          "\n     .word    0xDFFE2121    "\
          "\n     .word    0xD8A87070    "\
          "\n     .word    0x0CFDF1F1    "\
          "\n     .word    0x7A196363    "\
          "\n     .word    0x582F7777    "\
          "\n     .word    0x9F30AFAF    "\
          "\n     .word    0xA5E74242    "\
          "\n     .word    0x50702020    "\
          "\n     .word    0x2ECBE5E5    "\
          "\n     .word    0x12EFFDFD    "\
          "\n     .word    0xB708BFBF    "\
          "\n     .word    0xD4558181    "\
          "\n     .word    0x3C241818    "\
          "\n     .word    0x5F792626    "\
          "\n     .word    0x71B2C3C3    "\
          "\n     .word    0x3886BEBE    "\
          "\n     .word    0xFDC83535    "\
          "\n     .word    0x4FC78888    "\
          "\n     .word    0x4B652E2E    "\
          "\n     .word    0xF96A9393    "\
          "\n     .word    0x0D585555    "\
          "\n     .word    0x9D61FCFC    "\
          "\n     .word    0xC9B37A7A    "\
          "\n     .word    0xEF27C8C8    "\
          "\n     .word    0x3288BABA    "\
          "\n     .word    0x7D4F3232    "\
          "\n     .word    0xA442E6E6    "\
          "\n     .word    0xFB3BC0C0    "\
          "\n     .word    0xB3AA1919    "\
          "\n     .word    0x68F69E9E    "\
          "\n     .word    0x8122A3A3    "\
          "\n     .word    0xAAEE4444    "\
          "\n     .word    0x82D65454    "\
          "\n     .word    0xE6DD3B3B    "\
          "\n     .word    0x9E950B0B    "\
          "\n     .word    0x45C98C8C    "\
          "\n     .word    0x7BBCC7C7    "\
          "\n     .word    0x6E056B6B    "\
          "\n     .word    0x446C2828    "\
          "\n     .word    0x8B2CA7A7    "\
          "\n     .word    0x3D81BCBC    "\
          "\n     .word    0x27311616    "\
          "\n     .word    0x9A37ADAD    "\
          "\n     .word    0x4D96DBDB    "\
          "\n     .word    0xFA9E6464    "\
          "\n     .word    0xD2A67474    "\
          "\n     .word    0x22361414    "\
          "\n     .word    0x76E49292    "\
          "\n     .word    0x1E120C0C    "\
          "\n     .word    0xB4FC4848    "\
          "\n     .word    0x378FB8B8    "\
          "\n     .word    0xE7789F9F    "\
          "\n     .word    0xB20FBDBD    "\
          "\n     .word    0x2A694343    "\
          "\n     .word    0xF135C4C4    "\
          "\n     .word    0xE3DA3939    "\
          "\n     .word    0xF7C63131    "\
          "\n     .word    0x598AD3D3    "\
          "\n     .word    0x8674F2F2    "\
          "\n     .word    0x5683D5D5    "\
          "\n     .word    0xC54E8B8B    "\
          "\n     .word    0xEB856E6E    "\
          "\n     .word    0xC218DADA    "\
          "\n     .word    0x8F8E0101    "\
          "\n     .word    0xAC1DB1B1    "\
          "\n     .word    0x6DF19C9C    "\
          "\n     .word    0x3B724949    "\
          "\n     .word    0xC71FD8D8    "\
          "\n     .word    0x15B9ACAC    "\
          "\n     .word    0x09FAF3F3    "\
          "\n     .word    0x6FA0CFCF    "\
          "\n     .word    0xEA20CACA    "\
          "\n     .word    0x897DF4F4    "\
          "\n     .word    0x20674747    "\
          "\n     .word    0x28381010    "\
          "\n     .word    0x640B6F6F    "\
          "\n     .word    0x8373F0F0    "\
          "\n     .word    0xB1FB4A4A    "\
          "\n     .word    0x96CA5C5C    "\
          "\n     .word    0x6C543838    "\
          "\n     .word    0x085F5757    "\
          "\n     .word    0x52217373    "\
          "\n     .word    0xF3649797    "\
          "\n     .word    0x65AECBCB    "\
          "\n     .word    0x8425A1A1    "\
          "\n     .word    0xBF57E8E8    "\
          "\n     .word    0x635D3E3E    "\
          "\n     .word    0x7CEA9696    "\
          "\n     .word    0x7F1E6161    "\
          "\n     .word    0x919C0D0D    "\
          "\n     .word    0x949B0F0F    "\
          "\n     .word    0xAB4BE0E0    "\
          "\n     .word    0xC6BA7C7C    "\
          "\n     .word    0x57267171    "\
          "\n     .word    0xE529CCCC    "\
          "\n     .word    0x73E39090    "\
          "\n     .word    0x0F090606    "\
          "\n     .word    0x03F4F7F7    "\
          "\n     .word    0x362A1C1C    "\
          "\n     .word    0xFE3CC2C2    "\
          "\n     .word    0xE18B6A6A    "\
          "\n     .word    0x10BEAEAE    "\
          "\n     .word    0x6B026969    "\
          "\n     .word    0xA8BF1717    "\
          "\n     .word    0xE8719999    "\
          "\n     .word    0x69533A3A    "\
          "\n     .word    0xD0F72727    "\
          "\n     .word    0x4891D9D9    "\
          "\n     .word    0x35DEEBEB    "\
          "\n     .word    0xCEE52B2B    "\
          "\n     .word    0x55772222    "\
          "\n     .word    0xD604D2D2    "\
          "\n     .word    0x9039A9A9    "\
          "\n     .word    0x80870707    "\
          "\n     .word    0xF2C13333    "\
          "\n     .word    0xC1EC2D2D    "\
          "\n     .word    0x665A3C3C    "\
          "\n     .word    0xADB81515    "\
          "\n     .word    0x60A9C9C9    "\
          "\n     .word    0xDB5C8787    "\
          "\n     .word    0x1AB0AAAA    "\
          "\n     .word    0x88D85050    "\
          "\n     .word    0x8E2BA5A5    "\
          "\n     .word    0x8A890303    "\
          "\n     .word    0x134A5959    "\
          "\n     .word    0x9B920909    "\
          "\n     .word    0x39231A1A    "\
          "\n     .word    0x75106565    "\
          "\n     .word    0x5384D7D7    "\
          "\n     .word    0x51D58484    "\
          "\n     .word    0xD303D0D0    "\
          "\n     .word    0x5EDC8282    "\
          "\n     .word    0xCBE22929    "\
          "\n     .word    0x99C35A5A    "\
          "\n     .word    0x332D1E1E    "\
          "\n     .word    0x463D7B7B    "\
          "\n     .word    0x1FB7A8A8    "\
          "\n     .word    0x610C6D6D    "\
          "\n     .word    0x4E622C2C    "\
          "\n T1dn:                      "\
          "\n     .word    0xA597F4A5    "\
          "\n     .word    0x84EB9784    "\
          "\n     .word    0x99C7B099    "\
          "\n     .word    0x8DF78C8D    "\
          "\n     .word    0x0DE5170D    "\
          "\n     .word    0xBDB7DCBD    "\
          "\n     .word    0xB1A7C8B1    "\
          "\n     .word    0x5439FC54    "\
          "\n     .word    0x50C0F050    "\
          "\n     .word    0x03040503    "\
          "\n     .word    0xA987E0A9    "\
          "\n     .word    0x7DAC877D    "\
          "\n     .word    0x19D52B19    "\
          "\n     .word    0x6271A662    "\
          "\n     .word    0xE69A31E6    "\
          "\n     .word    0x9AC3B59A    "\
          "\n     .word    0x4505CF45    "\
          "\n     .word    0x9D3EBC9D    "\
          "\n     .word    0x4009C040    "\
          "\n     .word    0x87EF9287    "\
          "\n     .word    0x15C53F15    "\
          "\n     .word    0xEB7F26EB    "\
          "\n     .word    0xC90740C9    "\
          "\n     .word    0x0BED1D0B    "\
          "\n     .word    0xEC822FEC    "\
          "\n     .word    0x677DA967    "\
          "\n     .word    0xFDBE1CFD    "\
          "\n     .word    0xEA8A25EA    "\
          "\n     .word    0xBF46DABF    "\
          "\n     .word    0xF7A602F7    "\
          "\n     .word    0x96D3A196    "\
          "\n     .word    0x5B2DED5B    "\
          "\n     .word    0xC2EA5DC2    "\
          "\n     .word    0x1CD9241C    "\
          "\n     .word    0xAE7AE9AE    "\
          "\n     .word    0x6A98BE6A    "\
          "\n     .word    0x5AD8EE5A    "\
          "\n     .word    0x41FCC341    "\
          "\n     .word    0x02F10602    "\
          "\n     .word    0x4F1DD14F    "\
          "\n     .word    0x5CD0E45C    "\
          "\n     .word    0xF4A207F4    "\
          "\n     .word    0x34B95C34    "\
          "\n     .word    0x08E91808    "\
          "\n     .word    0x93DFAE93    "\
          "\n     .word    0x734D9573    "\
          "\n     .word    0x53C4F553    "\
          "\n     .word    0x3F54413F    "\
          "\n     .word    0x0C10140C    "\
          "\n     .word    0x5231F652    "\
          "\n     .word    0x658CAF65    "\
          "\n     .word    0x5E21E25E    "\
          "\n     .word    0x28607828    "\
          "\n     .word    0xA16EF8A1    "\
          "\n     .word    0x0F14110F    "\
          "\n     .word    0xB55EC4B5    "\
          "\n     .word    0x091C1B09    "\
          "\n     .word    0x36485A36    "\
          "\n     .word    0x9B36B69B    "\
          "\n     .word    0x3DA5473D    "\
          "\n     .word    0x26816A26    "\
          "\n     .word    0x699CBB69    "\
          "\n     .word    0xCDFE4CCD    "\
          "\n     .word    0x9FCFBA9F    "\
          "\n     .word    0x1B242D1B    "\
          "\n     .word    0x9E3AB99E    "\
          "\n     .word    0x74B09C74    "\
          "\n     .word    0x2E68722E    "\
          "\n     .word    0x2D6C772D    "\
          "\n     .word    0xB2A3CDB2    "\
          "\n     .word    0xEE7329EE    "\
          "\n     .word    0xFBB616FB    "\
          "\n     .word    0xF65301F6    "\
          "\n     .word    0x4DECD74D    "\
          "\n     .word    0x6175A361    "\
          "\n     .word    0xCEFA49CE    "\
          "\n     .word    0x7BA48D7B    "\
          "\n     .word    0x3EA1423E    "\
          "\n     .word    0x71BC9371    "\
          "\n     .word    0x9726A297    "\
          "\n     .word    0xF55704F5    "\
          "\n     .word    0x6869B868    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0x2C99742C    "\
          "\n     .word    0x6080A060    "\
          "\n     .word    0x1FDD211F    "\
          "\n     .word    0xC8F243C8    "\
          "\n     .word    0xED772CED    "\
          "\n     .word    0xBEB3D9BE    "\
          "\n     .word    0x4601CA46    "\
          "\n     .word    0xD9CE70D9    "\
          "\n     .word    0x4BE4DD4B    "\
          "\n     .word    0xDE3379DE    "\
          "\n     .word    0xD42B67D4    "\
          "\n     .word    0xE87B23E8    "\
          "\n     .word    0x4A11DE4A    "\
          "\n     .word    0x6B6DBD6B    "\
          "\n     .word    0x2A917E2A    "\
          "\n     .word    0xE59E34E5    "\
          "\n     .word    0x16C13A16    "\
          "\n     .word    0xC51754C5    "\
          "\n     .word    0xD72F62D7    "\
          "\n     .word    0x55CCFF55    "\
          "\n     .word    0x9422A794    "\
          "\n     .word    0xCF0F4ACF    "\
          "\n     .word    0x10C93010    "\
          "\n     .word    0x06080A06    "\
          "\n     .word    0x81E79881    "\
          "\n     .word    0xF05B0BF0    "\
          "\n     .word    0x44F0CC44    "\
          "\n     .word    0xBA4AD5BA    "\
          "\n     .word    0xE3963EE3    "\
          "\n     .word    0xF35F0EF3    "\
          "\n     .word    0xFEBA19FE    "\
          "\n     .word    0xC01B5BC0    "\
          "\n     .word    0x8A0A858A    "\
          "\n     .word    0xAD7EECAD    "\
          "\n     .word    0xBC42DFBC    "\
          "\n     .word    0x48E0D848    "\
          "\n     .word    0x04F90C04    "\
          "\n     .word    0xDFC67ADF    "\
          "\n     .word    0xC1EE58C1    "\
          "\n     .word    0x75459F75    "\
          "\n     .word    0x6384A563    "\
          "\n     .word    0x30405030    "\
          "\n     .word    0x1AD12E1A    "\
          "\n     .word    0x0EE1120E    "\
          "\n     .word    0x6D65B76D    "\
          "\n     .word    0x4C19D44C    "\
          "\n     .word    0x14303C14    "\
          "\n     .word    0x354C5F35    "\
          "\n     .word    0x2F9D712F    "\
          "\n     .word    0xE16738E1    "\
          "\n     .word    0xA26AFDA2    "\
          "\n     .word    0xCC0B4FCC    "\
          "\n     .word    0x395C4B39    "\
          "\n     .word    0x573DF957    "\
          "\n     .word    0xF2AA0DF2    "\
          "\n     .word    0x82E39D82    "\
          "\n     .word    0x47F4C947    "\
          "\n     .word    0xAC8BEFAC    "\
          "\n     .word    0xE76F32E7    "\
          "\n     .word    0x2B647D2B    "\
          "\n     .word    0x95D7A495    "\
          "\n     .word    0xA09BFBA0    "\
          "\n     .word    0x9832B398    "\
          "\n     .word    0xD12768D1    "\
          "\n     .word    0x7F5D817F    "\
          "\n     .word    0x6688AA66    "\
          "\n     .word    0x7EA8827E    "\
          "\n     .word    0xAB76E6AB    "\
          "\n     .word    0x83169E83    "\
          "\n     .word    0xCA0345CA    "\
          "\n     .word    0x29957B29    "\
          "\n     .word    0xD3D66ED3    "\
          "\n     .word    0x3C50443C    "\
          "\n     .word    0x79558B79    "\
          "\n     .word    0xE2633DE2    "\
          "\n     .word    0x1D2C271D    "\
          "\n     .word    0x76419A76    "\
          "\n     .word    0x3BAD4D3B    "\
          "\n     .word    0x56C8FA56    "\
          "\n     .word    0x4EE8D24E    "\
          "\n     .word    0x1E28221E    "\
          "\n     .word    0xDB3F76DB    "\
          "\n     .word    0x0A181E0A    "\
          "\n     .word    0x6C90B46C    "\
          "\n     .word    0xE46B37E4    "\
          "\n     .word    0x5D25E75D    "\
          "\n     .word    0x6E61B26E    "\
          "\n     .word    0xEF862AEF    "\
          "\n     .word    0xA693F1A6    "\
          "\n     .word    0xA872E3A8    "\
          "\n     .word    0xA462F7A4    "\
          "\n     .word    0x37BD5937    "\
          "\n     .word    0x8BFF868B    "\
          "\n     .word    0x32B15632    "\
          "\n     .word    0x430DC543    "\
          "\n     .word    0x59DCEB59    "\
          "\n     .word    0xB7AFC2B7    "\
          "\n     .word    0x8C028F8C    "\
          "\n     .word    0x6479AC64    "\
          "\n     .word    0xD2236DD2    "\
          "\n     .word    0xE0923BE0    "\
          "\n     .word    0xB4ABC7B4    "\
          "\n     .word    0xFA4315FA    "\
          "\n     .word    0x07FD0907    "\
          "\n     .word    0x25856F25    "\
          "\n     .word    0xAF8FEAAF    "\
          "\n     .word    0x8EF3898E    "\
          "\n     .word    0xE98E20E9    "\
          "\n     .word    0x18202818    "\
          "\n     .word    0xD5DE64D5    "\
          "\n     .word    0x88FB8388    "\
          "\n     .word    0x6F94B16F    "\
          "\n     .word    0x72B89672    "\
          "\n     .word    0x24706C24    "\
          "\n     .word    0xF1AE08F1    "\
          "\n     .word    0xC7E652C7    "\
          "\n     .word    0x5135F351    "\
          "\n     .word    0x238D6523    "\
          "\n     .word    0x7C59847C    "\
          "\n     .word    0x9CCBBF9C    "\
          "\n     .word    0x217C6321    "\
          "\n     .word    0xDD377CDD    "\
          "\n     .word    0xDCC27FDC    "\
          "\n     .word    0x861A9186    "\
          "\n     .word    0x851E9485    "\
          "\n     .word    0x90DBAB90    "\
          "\n     .word    0x42F8C642    "\
          "\n     .word    0xC4E257C4    "\
          "\n     .word    0xAA83E5AA    "\
          "\n     .word    0xD83B73D8    "\
          "\n     .word    0x050C0F05    "\
          "\n     .word    0x01F50301    "\
          "\n     .word    0x12383612    "\
          "\n     .word    0xA39FFEA3    "\
          "\n     .word    0x5FD4E15F    "\
          "\n     .word    0xF94710F9    "\
          "\n     .word    0xD0D26BD0    "\
          "\n     .word    0x912EA891    "\
          "\n     .word    0x5829E858    "\
          "\n     .word    0x27746927    "\
          "\n     .word    0xB94ED0B9    "\
          "\n     .word    0x38A94838    "\
          "\n     .word    0x13CD3513    "\
          "\n     .word    0xB356CEB3    "\
          "\n     .word    0x33445533    "\
          "\n     .word    0xBBBFD6BB    "\
          "\n     .word    0x70499070    "\
          "\n     .word    0x890E8089    "\
          "\n     .word    0xA766F2A7    "\
          "\n     .word    0xB65AC1B6    "\
          "\n     .word    0x22786622    "\
          "\n     .word    0x922AAD92    "\
          "\n     .word    0x20896020    "\
          "\n     .word    0x4915DB49    "\
          "\n     .word    0xFF4F1AFF    "\
          "\n     .word    0x78A08878    "\
          "\n     .word    0x7A518E7A    "\
          "\n     .word    0x8F068A8F    "\
          "\n     .word    0xF8B213F8    "\
          "\n     .word    0x80129B80    "\
          "\n     .word    0x17343917    "\
          "\n     .word    0xDACA75DA    "\
          "\n     .word    0x31B55331    "\
          "\n     .word    0xC61351C6    "\
          "\n     .word    0xB8BBD3B8    "\
          "\n     .word    0xC31F5EC3    "\
          "\n     .word    0xB052CBB0    "\
          "\n     .word    0x77B49977    "\
          "\n     .word    0x113C3311    "\
          "\n     .word    0xCBF646CB    "\
          "\n     .word    0xFC4B1FFC    "\
          "\n     .word    0xD6DA61D6    "\
          "\n     .word    0x3A584E3A    "\
          "\n T2up:                      "\
          "\n     .word    0x32C6C6A5    "\
          "\n     .word    0x6FF8F884    "\
          "\n     .word    0x5EEEEE99    "\
          "\n     .word    0x7AF6F68D    "\
          "\n     .word    0xE8FFFF0D    "\
          "\n     .word    0x0AD6D6BD    "\
          "\n     .word    0x16DEDEB1    "\
          "\n     .word    0x6D919154    "\
          "\n     .word    0x90606050    "\
          "\n     .word    0x07020203    "\
          "\n     .word    0x2ECECEA9    "\
          "\n     .word    0xD156567D    "\
          "\n     .word    0xCCE7E719    "\
          "\n     .word    0x13B5B562    "\
          "\n     .word    0x7C4D4DE6    "\
          "\n     .word    0x59ECEC9A    "\
          "\n     .word    0x408F8F45    "\
          "\n     .word    0xA31F1F9D    "\
          "\n     .word    0x49898940    "\
          "\n     .word    0x68FAFA87    "\
          "\n     .word    0xD0EFEF15    "\
          "\n     .word    0x94B2B2EB    "\
          "\n     .word    0xCE8E8EC9    "\
          "\n     .word    0xE6FBFB0B    "\
          "\n     .word    0x6E4141EC    "\
          "\n     .word    0x1AB3B367    "\
          "\n     .word    0x435F5FFD    "\
          "\n     .word    0x604545EA    "\
          "\n     .word    0xF92323BF    "\
          "\n     .word    0x515353F7    "\
          "\n     .word    0x45E4E496    "\
          "\n     .word    0x769B9B5B    "\
          "\n     .word    0x287575C2    "\
          "\n     .word    0xC5E1E11C    "\
          "\n     .word    0xD43D3DAE    "\
          "\n     .word    0xF24C4C6A    "\
          "\n     .word    0x826C6C5A    "\
          "\n     .word    0xBD7E7E41    "\
          "\n     .word    0xF3F5F502    "\
          "\n     .word    0x5283834F    "\
          "\n     .word    0x8C68685C    "\
          "\n     .word    0x565151F4    "\
          "\n     .word    0x8DD1D134    "\
          "\n     .word    0xE1F9F908    "\
          "\n     .word    0x4CE2E293    "\
          "\n     .word    0x3EABAB73    "\
          "\n     .word    0x97626253    "\
          "\n     .word    0x6B2A2A3F    "\
          "\n     .word    0x1C08080C    "\
          "\n     .word    0x63959552    "\
          "\n     .word    0xE9464665    "\
          "\n     .word    0x7F9D9D5E    "\
          "\n     .word    0x48303028    "\
          "\n     .word    0xCF3737A1    "\
          "\n     .word    0x1B0A0A0F    "\
          "\n     .word    0xEB2F2FB5    "\
          "\n     .word    0x150E0E09    "\
          "\n     .word    0x7E242436    "\
          "\n     .word    0xAD1B1B9B    "\
          "\n     .word    0x98DFDF3D    "\
          "\n     .word    0xA7CDCD26    "\
          "\n     .word    0xF54E4E69    "\
          "\n     .word    0x337F7FCD    "\
          "\n     .word    0x50EAEA9F    "\
          "\n     .word    0x3F12121B    "\
          "\n     .word    0xA41D1D9E    "\
          "\n     .word    0xC4585874    "\
          "\n     .word    0x4634342E    "\
          "\n     .word    0x4136362D    "\
          "\n     .word    0x11DCDCB2    "\
          "\n     .word    0x9DB4B4EE    "\
          "\n     .word    0x4D5B5BFB    "\
          "\n     .word    0xA5A4A4F6    "\
          "\n     .word    0xA176764D    "\
          "\n     .word    0x14B7B761    "\
          "\n     .word    0x347D7DCE    "\
          "\n     .word    0xDF52527B    "\
          "\n     .word    0x9FDDDD3E    "\
          "\n     .word    0xCD5E5E71    "\
          "\n     .word    0xB1131397    "\
          "\n     .word    0xA2A6A6F5    "\
          "\n     .word    0x01B9B968    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0xB5C1C12C    "\
          "\n     .word    0xE0404060    "\
          "\n     .word    0xC2E3E31F    "\
          "\n     .word    0x3A7979C8    "\
          "\n     .word    0x9AB6B6ED    "\
          "\n     .word    0x0DD4D4BE    "\
          "\n     .word    0x478D8D46    "\
          "\n     .word    0x176767D9    "\
          "\n     .word    0xAF72724B    "\
          "\n     .word    0xED9494DE    "\
          "\n     .word    0xFF9898D4    "\
          "\n     .word    0x93B0B0E8    "\
          "\n     .word    0x5B85854A    "\
          "\n     .word    0x06BBBB6B    "\
          "\n     .word    0xBBC5C52A    "\
          "\n     .word    0x7B4F4FE5    "\
          "\n     .word    0xD7EDED16    "\
          "\n     .word    0xD28686C5    "\
          "\n     .word    0xF89A9AD7    "\
          "\n     .word    0x99666655    "\
          "\n     .word    0xB6111194    "\
          "\n     .word    0xC08A8ACF    "\
          "\n     .word    0xD9E9E910    "\
          "\n     .word    0x0E040406    "\
          "\n     .word    0x66FEFE81    "\
          "\n     .word    0xABA0A0F0    "\
          "\n     .word    0xB4787844    "\
          "\n     .word    0xF02525BA    "\
          "\n     .word    0x754B4BE3    "\
          "\n     .word    0xACA2A2F3    "\
          "\n     .word    0x445D5DFE    "\
          "\n     .word    0xDB8080C0    "\
          "\n     .word    0x8005058A    "\
          "\n     .word    0xD33F3FAD    "\
          "\n     .word    0xFE2121BC    "\
          "\n     .word    0xA8707048    "\
          "\n     .word    0xFDF1F104    "\
          "\n     .word    0x196363DF    "\
          "\n     .word    0x2F7777C1    "\
          "\n     .word    0x30AFAF75    "\
          "\n     .word    0xE7424263    "\
          "\n     .word    0x70202030    "\
          "\n     .word    0xCBE5E51A    "\
          "\n     .word    0xEFFDFD0E    "\
          "\n     .word    0x08BFBF6D    "\
          "\n     .word    0x5581814C    "\
          "\n     .word    0x24181814    "\
          "\n     .word    0x79262635    "\
          "\n     .word    0xB2C3C32F    "\
          "\n     .word    0x86BEBEE1    "\
          "\n     .word    0xC83535A2    "\
          "\n     .word    0xC78888CC    "\
          "\n     .word    0x652E2E39    "\
          "\n     .word    0x6A939357    "\
          "\n     .word    0x585555F2    "\
          "\n     .word    0x61FCFC82    "\
          "\n     .word    0xB37A7A47    "\
          "\n     .word    0x27C8C8AC    "\
          "\n     .word    0x88BABAE7    "\
          "\n     .word    0x4F32322B    "\
          "\n     .word    0x42E6E695    "\
          "\n     .word    0x3BC0C0A0    "\
          "\n     .word    0xAA191998    "\
          "\n     .word    0xF69E9ED1    "\
          "\n     .word    0x22A3A37F    "\
          "\n     .word    0xEE444466    "\
          "\n     .word    0xD654547E    "\
          "\n     .word    0xDD3B3BAB    "\
          "\n     .word    0x950B0B83    "\
          "\n     .word    0xC98C8CCA    "\
          "\n     .word    0xBCC7C729    "\
          "\n     .word    0x056B6BD3    "\
          "\n     .word    0x6C28283C    "\
          "\n     .word    0x2CA7A779    "\
          "\n     .word    0x81BCBCE2    "\
          "\n     .word    0x3116161D    "\
          "\n     .word    0x37ADAD76    "\
          "\n     .word    0x96DBDB3B    "\
          "\n     .word    0x9E646456    "\
          "\n     .word    0xA674744E    "\
          "\n     .word    0x3614141E    "\
          "\n     .word    0xE49292DB    "\
          "\n     .word    0x120C0C0A    "\
          "\n     .word    0xFC48486C    "\
          "\n     .word    0x8FB8B8E4    "\
          "\n     .word    0x789F9F5D    "\
          "\n     .word    0x0FBDBD6E    "\
          "\n     .word    0x694343EF    "\
          "\n     .word    0x35C4C4A6    "\
          "\n     .word    0xDA3939A8    "\
          "\n     .word    0xC63131A4    "\
          "\n     .word    0x8AD3D337    "\
          "\n     .word    0x74F2F28B    "\
          "\n     .word    0x83D5D532    "\
          "\n     .word    0x4E8B8B43    "\
          "\n     .word    0x856E6E59    "\
          "\n     .word    0x18DADAB7    "\
          "\n     .word    0x8E01018C    "\
          "\n     .word    0x1DB1B164    "\
          "\n     .word    0xF19C9CD2    "\
          "\n     .word    0x724949E0    "\
          "\n     .word    0x1FD8D8B4    "\
          "\n     .word    0xB9ACACFA    "\
          "\n     .word    0xFAF3F307    "\
          "\n     .word    0xA0CFCF25    "\
          "\n     .word    0x20CACAAF    "\
          "\n     .word    0x7DF4F48E    "\
          "\n     .word    0x674747E9    "\
          "\n     .word    0x38101018    "\
          "\n     .word    0x0B6F6FD5    "\
          "\n     .word    0x73F0F088    "\
          "\n     .word    0xFB4A4A6F    "\
          "\n     .word    0xCA5C5C72    "\
          "\n     .word    0x54383824    "\
          "\n     .word    0x5F5757F1    "\
          "\n     .word    0x217373C7    "\
          "\n     .word    0x64979751    "\
          "\n     .word    0xAECBCB23    "\
          "\n     .word    0x25A1A17C    "\
          "\n     .word    0x57E8E89C    "\
          "\n     .word    0x5D3E3E21    "\
          "\n     .word    0xEA9696DD    "\
          "\n     .word    0x1E6161DC    "\
          "\n     .word    0x9C0D0D86    "\
          "\n     .word    0x9B0F0F85    "\
          "\n     .word    0x4BE0E090    "\
          "\n     .word    0xBA7C7C42    "\
          "\n     .word    0x267171C4    "\
          "\n     .word    0x29CCCCAA    "\
          "\n     .word    0xE39090D8    "\
          "\n     .word    0x09060605    "\
          "\n     .word    0xF4F7F701    "\
          "\n     .word    0x2A1C1C12    "\
          "\n     .word    0x3CC2C2A3    "\
          "\n     .word    0x8B6A6A5F    "\
          "\n     .word    0xBEAEAEF9    "\
          "\n     .word    0x026969D0    "\
          "\n     .word    0xBF171791    "\
          "\n     .word    0x71999958    "\
          "\n     .word    0x533A3A27    "\
          "\n     .word    0xF72727B9    "\
          "\n     .word    0x91D9D938    "\
          "\n     .word    0xDEEBEB13    "\
          "\n     .word    0xE52B2BB3    "\
          "\n     .word    0x77222233    "\
          "\n     .word    0x04D2D2BB    "\
          "\n     .word    0x39A9A970    "\
          "\n     .word    0x87070789    "\
          "\n     .word    0xC13333A7    "\
          "\n     .word    0xEC2D2DB6    "\
          "\n     .word    0x5A3C3C22    "\
          "\n     .word    0xB8151592    "\
          "\n     .word    0xA9C9C920    "\
          "\n     .word    0x5C878749    "\
          "\n     .word    0xB0AAAAFF    "\
          "\n     .word    0xD8505078    "\
          "\n     .word    0x2BA5A57A    "\
          "\n     .word    0x8903038F    "\
          "\n     .word    0x4A5959F8    "\
          "\n     .word    0x92090980    "\
          "\n     .word    0x231A1A17    "\
          "\n     .word    0x106565DA    "\
          "\n     .word    0x84D7D731    "\
          "\n     .word    0xD58484C6    "\
          "\n     .word    0x03D0D0B8    "\
          "\n     .word    0xDC8282C3    "\
          "\n     .word    0xE22929B0    "\
          "\n     .word    0xC35A5A77    "\
          "\n     .word    0x2D1E1E11    "\
          "\n     .word    0x3D7B7BCB    "\
          "\n     .word    0xB7A8A8FC    "\
          "\n     .word    0x0C6D6DD6    "\
          "\n     .word    0x622C2C3A    "\
          "\n T2dn:                      "\
          "\n     .word    0x97F4A5F4    "\
          "\n     .word    0xEB978497    "\
          "\n     .word    0xC7B099B0    "\
          "\n     .word    0xF78C8D8C    "\
          "\n     .word    0xE5170D17    "\
          "\n     .word    0xB7DCBDDC    "\
          "\n     .word    0xA7C8B1C8    "\
          "\n     .word    0x39FC54FC    "\
          "\n     .word    0xC0F050F0    "\
          "\n     .word    0x04050305    "\
          "\n     .word    0x87E0A9E0    "\
          "\n     .word    0xAC877D87    "\
          "\n     .word    0xD52B192B    "\
          "\n     .word    0x71A662A6    "\
          "\n     .word    0x9A31E631    "\
          "\n     .word    0xC3B59AB5    "\
          "\n     .word    0x05CF45CF    "\
          "\n     .word    0x3EBC9DBC    "\
          "\n     .word    0x09C040C0    "\
          "\n     .word    0xEF928792    "\
          "\n     .word    0xC53F153F    "\
          "\n     .word    0x7F26EB26    "\
          "\n     .word    0x0740C940    "\
          "\n     .word    0xED1D0B1D    "\
          "\n     .word    0x822FEC2F    "\
          "\n     .word    0x7DA967A9    "\
          "\n     .word    0xBE1CFD1C    "\
          "\n     .word    0x8A25EA25    "\
          "\n     .word    0x46DABFDA    "\
          "\n     .word    0xA602F702    "\
          "\n     .word    0xD3A196A1    "\
          "\n     .word    0x2DED5BED    "\
          "\n     .word    0xEA5DC25D    "\
          "\n     .word    0xD9241C24    "\
          "\n     .word    0x7AE9AEE9    "\
          "\n     .word    0x98BE6ABE    "\
          "\n     .word    0xD8EE5AEE    "\
          "\n     .word    0xFCC341C3    "\
          "\n     .word    0xF1060206    "\
          "\n     .word    0x1DD14FD1    "\
          "\n     .word    0xD0E45CE4    "\
          "\n     .word    0xA207F407    "\
          "\n     .word    0xB95C345C    "\
          "\n     .word    0xE9180818    "\
          "\n     .word    0xDFAE93AE    "\
          "\n     .word    0x4D957395    "\
          "\n     .word    0xC4F553F5    "\
          "\n     .word    0x54413F41    "\
          "\n     .word    0x10140C14    "\
          "\n     .word    0x31F652F6    "\
          "\n     .word    0x8CAF65AF    "\
          "\n     .word    0x21E25EE2    "\
          "\n     .word    0x60782878    "\
          "\n     .word    0x6EF8A1F8    "\
          "\n     .word    0x14110F11    "\
          "\n     .word    0x5EC4B5C4    "\
          "\n     .word    0x1C1B091B    "\
          "\n     .word    0x485A365A    "\
          "\n     .word    0x36B69BB6    "\
          "\n     .word    0xA5473D47    "\
          "\n     .word    0x816A266A    "\
          "\n     .word    0x9CBB69BB    "\
          "\n     .word    0xFE4CCD4C    "\
          "\n     .word    0xCFBA9FBA    "\
          "\n     .word    0x242D1B2D    "\
          "\n     .word    0x3AB99EB9    "\
          "\n     .word    0xB09C749C    "\
          "\n     .word    0x68722E72    "\
          "\n     .word    0x6C772D77    "\
          "\n     .word    0xA3CDB2CD    "\
          "\n     .word    0x7329EE29    "\
          "\n     .word    0xB616FB16    "\
          "\n     .word    0x5301F601    "\
          "\n     .word    0xECD74DD7    "\
          "\n     .word    0x75A361A3    "\
          "\n     .word    0xFA49CE49    "\
          "\n     .word    0xA48D7B8D    "\
          "\n     .word    0xA1423E42    "\
          "\n     .word    0xBC937193    "\
          "\n     .word    0x26A297A2    "\
          "\n     .word    0x5704F504    "\
          "\n     .word    0x69B868B8    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0x99742C74    "\
          "\n     .word    0x80A060A0    "\
          "\n     .word    0xDD211F21    "\
          "\n     .word    0xF243C843    "\
          "\n     .word    0x772CED2C    "\
          "\n     .word    0xB3D9BED9    "\
          "\n     .word    0x01CA46CA    "\
          "\n     .word    0xCE70D970    "\
          "\n     .word    0xE4DD4BDD    "\
          "\n     .word    0x3379DE79    "\
          "\n     .word    0x2B67D467    "\
          "\n     .word    0x7B23E823    "\
          "\n     .word    0x11DE4ADE    "\
          "\n     .word    0x6DBD6BBD    "\
          "\n     .word    0x917E2A7E    "\
          "\n     .word    0x9E34E534    "\
          "\n     .word    0xC13A163A    "\
          "\n     .word    0x1754C554    "\
          "\n     .word    0x2F62D762    "\
          "\n     .word    0xCCFF55FF    "\
          "\n     .word    0x22A794A7    "\
          "\n     .word    0x0F4ACF4A    "\
          "\n     .word    0xC9301030    "\
          "\n     .word    0x080A060A    "\
          "\n     .word    0xE7988198    "\
          "\n     .word    0x5B0BF00B    "\
          "\n     .word    0xF0CC44CC    "\
          "\n     .word    0x4AD5BAD5    "\
          "\n     .word    0x963EE33E    "\
          "\n     .word    0x5F0EF30E    "\
          "\n     .word    0xBA19FE19    "\
          "\n     .word    0x1B5BC05B    "\
          "\n     .word    0x0A858A85    "\
          "\n     .word    0x7EECADEC    "\
          "\n     .word    0x42DFBCDF    "\
          "\n     .word    0xE0D848D8    "\
          "\n     .word    0xF90C040C    "\
          "\n     .word    0xC67ADF7A    "\
          "\n     .word    0xEE58C158    "\
          "\n     .word    0x459F759F    "\
          "\n     .word    0x84A563A5    "\
          "\n     .word    0x40503050    "\
          "\n     .word    0xD12E1A2E    "\
          "\n     .word    0xE1120E12    "\
          "\n     .word    0x65B76DB7    "\
          "\n     .word    0x19D44CD4    "\
          "\n     .word    0x303C143C    "\
          "\n     .word    0x4C5F355F    "\
          "\n     .word    0x9D712F71    "\
          "\n     .word    0x6738E138    "\
          "\n     .word    0x6AFDA2FD    "\
          "\n     .word    0x0B4FCC4F    "\
          "\n     .word    0x5C4B394B    "\
          "\n     .word    0x3DF957F9    "\
          "\n     .word    0xAA0DF20D    "\
          "\n     .word    0xE39D829D    "\
          "\n     .word    0xF4C947C9    "\
          "\n     .word    0x8BEFACEF    "\
          "\n     .word    0x6F32E732    "\
          "\n     .word    0x647D2B7D    "\
          "\n     .word    0xD7A495A4    "\
          "\n     .word    0x9BFBA0FB    "\
          "\n     .word    0x32B398B3    "\
          "\n     .word    0x2768D168    "\
          "\n     .word    0x5D817F81    "\
          "\n     .word    0x88AA66AA    "\
          "\n     .word    0xA8827E82    "\
          "\n     .word    0x76E6ABE6    "\
          "\n     .word    0x169E839E    "\
          "\n     .word    0x0345CA45    "\
          "\n     .word    0x957B297B    "\
          "\n     .word    0xD66ED36E    "\
          "\n     .word    0x50443C44    "\
          "\n     .word    0x558B798B    "\
          "\n     .word    0x633DE23D    "\
          "\n     .word    0x2C271D27    "\
          "\n     .word    0x419A769A    "\
          "\n     .word    0xAD4D3B4D    "\
          "\n     .word    0xC8FA56FA    "\
          "\n     .word    0xE8D24ED2    "\
          "\n     .word    0x28221E22    "\
          "\n     .word    0x3F76DB76    "\
          "\n     .word    0x181E0A1E    "\
          "\n     .word    0x90B46CB4    "\
          "\n     .word    0x6B37E437    "\
          "\n     .word    0x25E75DE7    "\
          "\n     .word    0x61B26EB2    "\
          "\n     .word    0x862AEF2A    "\
          "\n     .word    0x93F1A6F1    "\
          "\n     .word    0x72E3A8E3    "\
          "\n     .word    0x62F7A4F7    "\
          "\n     .word    0xBD593759    "\
          "\n     .word    0xFF868B86    "\
          "\n     .word    0xB1563256    "\
          "\n     .word    0x0DC543C5    "\
          "\n     .word    0xDCEB59EB    "\
          "\n     .word    0xAFC2B7C2    "\
          "\n     .word    0x028F8C8F    "\
          "\n     .word    0x79AC64AC    "\
          "\n     .word    0x236DD26D    "\
          "\n     .word    0x923BE03B    "\
          "\n     .word    0xABC7B4C7    "\
          "\n     .word    0x4315FA15    "\
          "\n     .word    0xFD090709    "\
          "\n     .word    0x856F256F    "\
          "\n     .word    0x8FEAAFEA    "\
          "\n     .word    0xF3898E89    "\
          "\n     .word    0x8E20E920    "\
          "\n     .word    0x20281828    "\
          "\n     .word    0xDE64D564    "\
          "\n     .word    0xFB838883    "\
          "\n     .word    0x94B16FB1    "\
          "\n     .word    0xB8967296    "\
          "\n     .word    0x706C246C    "\
          "\n     .word    0xAE08F108    "\
          "\n     .word    0xE652C752    "\
          "\n     .word    0x35F351F3    "\
          "\n     .word    0x8D652365    "\
          "\n     .word    0x59847C84    "\
          "\n     .word    0xCBBF9CBF    "\
          "\n     .word    0x7C632163    "\
          "\n     .word    0x377CDD7C    "\
          "\n     .word    0xC27FDC7F    "\
          "\n     .word    0x1A918691    "\
          "\n     .word    0x1E948594    "\
          "\n     .word    0xDBAB90AB    "\
          "\n     .word    0xF8C642C6    "\
          "\n     .word    0xE257C457    "\
          "\n     .word    0x83E5AAE5    "\
          "\n     .word    0x3B73D873    "\
          "\n     .word    0x0C0F050F    "\
          "\n     .word    0xF5030103    "\
          "\n     .word    0x38361236    "\
          "\n     .word    0x9FFEA3FE    "\
          "\n     .word    0xD4E15FE1    "\
          "\n     .word    0x4710F910    "\
          "\n     .word    0xD26BD06B    "\
          "\n     .word    0x2EA891A8    "\
          "\n     .word    0x29E858E8    "\
          "\n     .word    0x74692769    "\
          "\n     .word    0x4ED0B9D0    "\
          "\n     .word    0xA9483848    "\
          "\n     .word    0xCD351335    "\
          "\n     .word    0x56CEB3CE    "\
          "\n     .word    0x44553355    "\
          "\n     .word    0xBFD6BBD6    "\
          "\n     .word    0x49907090    "\
          "\n     .word    0x0E808980    "\
          "\n     .word    0x66F2A7F2    "\
          "\n     .word    0x5AC1B6C1    "\
          "\n     .word    0x78662266    "\
          "\n     .word    0x2AAD92AD    "\
          "\n     .word    0x89602060    "\
          "\n     .word    0x15DB49DB    "\
          "\n     .word    0x4F1AFF1A    "\
          "\n     .word    0xA0887888    "\
          "\n     .word    0x518E7A8E    "\
          "\n     .word    0x068A8F8A    "\
          "\n     .word    0xB213F813    "\
          "\n     .word    0x129B809B    "\
          "\n     .word    0x34391739    "\
          "\n     .word    0xCA75DA75    "\
          "\n     .word    0xB5533153    "\
          "\n     .word    0x1351C651    "\
          "\n     .word    0xBBD3B8D3    "\
          "\n     .word    0x1F5EC35E    "\
          "\n     .word    0x52CBB0CB    "\
          "\n     .word    0xB4997799    "\
          "\n     .word    0x3C331133    "\
          "\n     .word    0xF646CB46    "\
          "\n     .word    0x4B1FFC1F    "\
          "\n     .word    0xDA61D661    "\
          "\n     .word    0x584E3A4E    "\
          "\n T3up:                      "\
          "\n     .word    0xC6C6A597    "\
          "\n     .word    0xF8F884EB    "\
          "\n     .word    0xEEEE99C7    "\
          "\n     .word    0xF6F68DF7    "\
          "\n     .word    0xFFFF0DE5    "\
          "\n     .word    0xD6D6BDB7    "\
          "\n     .word    0xDEDEB1A7    "\
          "\n     .word    0x91915439    "\
          "\n     .word    0x606050C0    "\
          "\n     .word    0x02020304    "\
          "\n     .word    0xCECEA987    "\
          "\n     .word    0x56567DAC    "\
          "\n     .word    0xE7E719D5    "\
          "\n     .word    0xB5B56271    "\
          "\n     .word    0x4D4DE69A    "\
          "\n     .word    0xECEC9AC3    "\
          "\n     .word    0x8F8F4505    "\
          "\n     .word    0x1F1F9D3E    "\
          "\n     .word    0x89894009    "\
          "\n     .word    0xFAFA87EF    "\
          "\n     .word    0xEFEF15C5    "\
          "\n     .word    0xB2B2EB7F    "\
          "\n     .word    0x8E8EC907    "\
          "\n     .word    0xFBFB0BED    "\
          "\n     .word    0x4141EC82    "\
          "\n     .word    0xB3B3677D    "\
          "\n     .word    0x5F5FFDBE    "\
          "\n     .word    0x4545EA8A    "\
          "\n     .word    0x2323BF46    "\
          "\n     .word    0x5353F7A6    "\
          "\n     .word    0xE4E496D3    "\
          "\n     .word    0x9B9B5B2D    "\
          "\n     .word    0x7575C2EA    "\
          "\n     .word    0xE1E11CD9    "\
          "\n     .word    0x3D3DAE7A    "\
          "\n     .word    0x4C4C6A98    "\
          "\n     .word    0x6C6C5AD8    "\
          "\n     .word    0x7E7E41FC    "\
          "\n     .word    0xF5F502F1    "\
          "\n     .word    0x83834F1D    "\
          "\n     .word    0x68685CD0    "\
          "\n     .word    0x5151F4A2    "\
          "\n     .word    0xD1D134B9    "\
          "\n     .word    0xF9F908E9    "\
          "\n     .word    0xE2E293DF    "\
          "\n     .word    0xABAB734D    "\
          "\n     .word    0x626253C4    "\
          "\n     .word    0x2A2A3F54    "\
          "\n     .word    0x08080C10    "\
          "\n     .word    0x95955231    "\
          "\n     .word    0x4646658C    "\
          "\n     .word    0x9D9D5E21    "\
          "\n     .word    0x30302860    "\
          "\n     .word    0x3737A16E    "\
          "\n     .word    0x0A0A0F14    "\
          "\n     .word    0x2F2FB55E    "\
          "\n     .word    0x0E0E091C    "\
          "\n     .word    0x24243648    "\
          "\n     .word    0x1B1B9B36    "\
          "\n     .word    0xDFDF3DA5    "\
          "\n     .word    0xCDCD2681    "\
          "\n     .word    0x4E4E699C    "\
          "\n     .word    0x7F7FCDFE    "\
          "\n     .word    0xEAEA9FCF    "\
          "\n     .word    0x12121B24    "\
          "\n     .word    0x1D1D9E3A    "\
          "\n     .word    0x585874B0    "\
          "\n     .word    0x34342E68    "\
          "\n     .word    0x36362D6C    "\
          "\n     .word    0xDCDCB2A3    "\
          "\n     .word    0xB4B4EE73    "\
          "\n     .word    0x5B5BFBB6    "\
          "\n     .word    0xA4A4F653    "\
          "\n     .word    0x76764DEC    "\
          "\n     .word    0xB7B76175    "\
          "\n     .word    0x7D7DCEFA    "\
          "\n     .word    0x52527BA4    "\
          "\n     .word    0xDDDD3EA1    "\
          "\n     .word    0x5E5E71BC    "\
          "\n     .word    0x13139726    "\
          "\n     .word    0xA6A6F557    "\
          "\n     .word    0xB9B96869    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0xC1C12C99    "\
          "\n     .word    0x40406080    "\
          "\n     .word    0xE3E31FDD    "\
          "\n     .word    0x7979C8F2    "\
          "\n     .word    0xB6B6ED77    "\
          "\n     .word    0xD4D4BEB3    "\
          "\n     .word    0x8D8D4601    "\
          "\n     .word    0x6767D9CE    "\
          "\n     .word    0x72724BE4    "\
          "\n     .word    0x9494DE33    "\
          "\n     .word    0x9898D42B    "\
          "\n     .word    0xB0B0E87B    "\
          "\n     .word    0x85854A11    "\
          "\n     .word    0xBBBB6B6D    "\
          "\n     .word    0xC5C52A91    "\
          "\n     .word    0x4F4FE59E    "\
          "\n     .word    0xEDED16C1    "\
          "\n     .word    0x8686C517    "\
          "\n     .word    0x9A9AD72F    "\
          "\n     .word    0x666655CC    "\
          "\n     .word    0x11119422    "\
          "\n     .word    0x8A8ACF0F    "\
          "\n     .word    0xE9E910C9    "\
          "\n     .word    0x04040608    "\
          "\n     .word    0xFEFE81E7    "\
          "\n     .word    0xA0A0F05B    "\
          "\n     .word    0x787844F0    "\
          "\n     .word    0x2525BA4A    "\
          "\n     .word    0x4B4BE396    "\
          "\n     .word    0xA2A2F35F    "\
          "\n     .word    0x5D5DFEBA    "\
          "\n     .word    0x8080C01B    "\
          "\n     .word    0x05058A0A    "\
          "\n     .word    0x3F3FAD7E    "\
          "\n     .word    0x2121BC42    "\
          "\n     .word    0x707048E0    "\
          "\n     .word    0xF1F104F9    "\
          "\n     .word    0x6363DFC6    "\
          "\n     .word    0x7777C1EE    "\
          "\n     .word    0xAFAF7545    "\
          "\n     .word    0x42426384    "\
          "\n     .word    0x20203040    "\
          "\n     .word    0xE5E51AD1    "\
          "\n     .word    0xFDFD0EE1    "\
          "\n     .word    0xBFBF6D65    "\
          "\n     .word    0x81814C19    "\
          "\n     .word    0x18181430    "\
          "\n     .word    0x2626354C    "\
          "\n     .word    0xC3C32F9D    "\
          "\n     .word    0xBEBEE167    "\
          "\n     .word    0x3535A26A    "\
          "\n     .word    0x8888CC0B    "\
          "\n     .word    0x2E2E395C    "\
          "\n     .word    0x9393573D    "\
          "\n     .word    0x5555F2AA    "\
          "\n     .word    0xFCFC82E3    "\
          "\n     .word    0x7A7A47F4    "\
          "\n     .word    0xC8C8AC8B    "\
          "\n     .word    0xBABAE76F    "\
          "\n     .word    0x32322B64    "\
          "\n     .word    0xE6E695D7    "\
          "\n     .word    0xC0C0A09B    "\
          "\n     .word    0x19199832    "\
          "\n     .word    0x9E9ED127    "\
          "\n     .word    0xA3A37F5D    "\
          "\n     .word    0x44446688    "\
          "\n     .word    0x54547EA8    "\
          "\n     .word    0x3B3BAB76    "\
          "\n     .word    0x0B0B8316    "\
          "\n     .word    0x8C8CCA03    "\
          "\n     .word    0xC7C72995    "\
          "\n     .word    0x6B6BD3D6    "\
          "\n     .word    0x28283C50    "\
          "\n     .word    0xA7A77955    "\
          "\n     .word    0xBCBCE263    "\
          "\n     .word    0x16161D2C    "\
          "\n     .word    0xADAD7641    "\
          "\n     .word    0xDBDB3BAD    "\
          "\n     .word    0x646456C8    "\
          "\n     .word    0x74744EE8    "\
          "\n     .word    0x14141E28    "\
          "\n     .word    0x9292DB3F    "\
          "\n     .word    0x0C0C0A18    "\
          "\n     .word    0x48486C90    "\
          "\n     .word    0xB8B8E46B    "\
          "\n     .word    0x9F9F5D25    "\
          "\n     .word    0xBDBD6E61    "\
          "\n     .word    0x4343EF86    "\
          "\n     .word    0xC4C4A693    "\
          "\n     .word    0x3939A872    "\
          "\n     .word    0x3131A462    "\
          "\n     .word    0xD3D337BD    "\
          "\n     .word    0xF2F28BFF    "\
          "\n     .word    0xD5D532B1    "\
          "\n     .word    0x8B8B430D    "\
          "\n     .word    0x6E6E59DC    "\
          "\n     .word    0xDADAB7AF    "\
          "\n     .word    0x01018C02    "\
          "\n     .word    0xB1B16479    "\
          "\n     .word    0x9C9CD223    "\
          "\n     .word    0x4949E092    "\
          "\n     .word    0xD8D8B4AB    "\
          "\n     .word    0xACACFA43    "\
          "\n     .word    0xF3F307FD    "\
          "\n     .word    0xCFCF2585    "\
          "\n     .word    0xCACAAF8F    "\
          "\n     .word    0xF4F48EF3    "\
          "\n     .word    0x4747E98E    "\
          "\n     .word    0x10101820    "\
          "\n     .word    0x6F6FD5DE    "\
          "\n     .word    0xF0F088FB    "\
          "\n     .word    0x4A4A6F94    "\
          "\n     .word    0x5C5C72B8    "\
          "\n     .word    0x38382470    "\
          "\n     .word    0x5757F1AE    "\
          "\n     .word    0x7373C7E6    "\
          "\n     .word    0x97975135    "\
          "\n     .word    0xCBCB238D    "\
          "\n     .word    0xA1A17C59    "\
          "\n     .word    0xE8E89CCB    "\
          "\n     .word    0x3E3E217C    "\
          "\n     .word    0x9696DD37    "\
          "\n     .word    0x6161DCC2    "\
          "\n     .word    0x0D0D861A    "\
          "\n     .word    0x0F0F851E    "\
          "\n     .word    0xE0E090DB    "\
          "\n     .word    0x7C7C42F8    "\
          "\n     .word    0x7171C4E2    "\
          "\n     .word    0xCCCCAA83    "\
          "\n     .word    0x9090D83B    "\
          "\n     .word    0x0606050C    "\
          "\n     .word    0xF7F701F5    "\
          "\n     .word    0x1C1C1238    "\
          "\n     .word    0xC2C2A39F    "\
          "\n     .word    0x6A6A5FD4    "\
          "\n     .word    0xAEAEF947    "\
          "\n     .word    0x6969D0D2    "\
          "\n     .word    0x1717912E    "\
          "\n     .word    0x99995829    "\
          "\n     .word    0x3A3A2774    "\
          "\n     .word    0x2727B94E    "\
          "\n     .word    0xD9D938A9    "\
          "\n     .word    0xEBEB13CD    "\
          "\n     .word    0x2B2BB356    "\
          "\n     .word    0x22223344    "\
          "\n     .word    0xD2D2BBBF    "\
          "\n     .word    0xA9A97049    "\
          "\n     .word    0x0707890E    "\
          "\n     .word    0x3333A766    "\
          "\n     .word    0x2D2DB65A    "\
          "\n     .word    0x3C3C2278    "\
          "\n     .word    0x1515922A    "\
          "\n     .word    0xC9C92089    "\
          "\n     .word    0x87874915    "\
          "\n     .word    0xAAAAFF4F    "\
          "\n     .word    0x505078A0    "\
          "\n     .word    0xA5A57A51    "\
          "\n     .word    0x03038F06    "\
          "\n     .word    0x5959F8B2    "\
          "\n     .word    0x09098012    "\
          "\n     .word    0x1A1A1734    "\
          "\n     .word    0x6565DACA    "\
          "\n     .word    0xD7D731B5    "\
          "\n     .word    0x8484C613    "\
          "\n     .word    0xD0D0B8BB    "\
          "\n     .word    0x8282C31F    "\
          "\n     .word    0x2929B052    "\
          "\n     .word    0x5A5A77B4    "\
          "\n     .word    0x1E1E113C    "\
          "\n     .word    0x7B7BCBF6    "\
          "\n     .word    0xA8A8FC4B    "\
          "\n     .word    0x6D6DD6DA    "\
          "\n     .word    0x2C2C3A58    "\
          "\n T3dn:                      "\
          "\n     .word    0xF4A5F432    "\
          "\n     .word    0x9784976F    "\
          "\n     .word    0xB099B05E    "\
          "\n     .word    0x8C8D8C7A    "\
          "\n     .word    0x170D17E8    "\
          "\n     .word    0xDCBDDC0A    "\
          "\n     .word    0xC8B1C816    "\
          "\n     .word    0xFC54FC6D    "\
          "\n     .word    0xF050F090    "\
          "\n     .word    0x05030507    "\
          "\n     .word    0xE0A9E02E    "\
          "\n     .word    0x877D87D1    "\
          "\n     .word    0x2B192BCC    "\
          "\n     .word    0xA662A613    "\
          "\n     .word    0x31E6317C    "\
          "\n     .word    0xB59AB559    "\
          "\n     .word    0xCF45CF40    "\
          "\n     .word    0xBC9DBCA3    "\
          "\n     .word    0xC040C049    "\
          "\n     .word    0x92879268    "\
          "\n     .word    0x3F153FD0    "\
          "\n     .word    0x26EB2694    "\
          "\n     .word    0x40C940CE    "\
          "\n     .word    0x1D0B1DE6    "\
          "\n     .word    0x2FEC2F6E    "\
          "\n     .word    0xA967A91A    "\
          "\n     .word    0x1CFD1C43    "\
          "\n     .word    0x25EA2560    "\
          "\n     .word    0xDABFDAF9    "\
          "\n     .word    0x02F70251    "\
          "\n     .word    0xA196A145    "\
          "\n     .word    0xED5BED76    "\
          "\n     .word    0x5DC25D28    "\
          "\n     .word    0x241C24C5    "\
          "\n     .word    0xE9AEE9D4    "\
          "\n     .word    0xBE6ABEF2    "\
          "\n     .word    0xEE5AEE82    "\
          "\n     .word    0xC341C3BD    "\
          "\n     .word    0x060206F3    "\
          "\n     .word    0xD14FD152    "\
          "\n     .word    0xE45CE48C    "\
          "\n     .word    0x07F40756    "\
          "\n     .word    0x5C345C8D    "\
          "\n     .word    0x180818E1    "\
          "\n     .word    0xAE93AE4C    "\
          "\n     .word    0x9573953E    "\
          "\n     .word    0xF553F597    "\
          "\n     .word    0x413F416B    "\
          "\n     .word    0x140C141C    "\
          "\n     .word    0xF652F663    "\
          "\n     .word    0xAF65AFE9    "\
          "\n     .word    0xE25EE27F    "\
          "\n     .word    0x78287848    "\
          "\n     .word    0xF8A1F8CF    "\
          "\n     .word    0x110F111B    "\
          "\n     .word    0xC4B5C4EB    "\
          "\n     .word    0x1B091B15    "\
          "\n     .word    0x5A365A7E    "\
          "\n     .word    0xB69BB6AD    "\
          "\n     .word    0x473D4798    "\
          "\n     .word    0x6A266AA7    "\
          "\n     .word    0xBB69BBF5    "\
          "\n     .word    0x4CCD4C33    "\
          "\n     .word    0xBA9FBA50    "\
          "\n     .word    0x2D1B2D3F    "\
          "\n     .word    0xB99EB9A4    "\
          "\n     .word    0x9C749CC4    "\
          "\n     .word    0x722E7246    "\
          "\n     .word    0x772D7741    "\
          "\n     .word    0xCDB2CD11    "\
          "\n     .word    0x29EE299D    "\
          "\n     .word    0x16FB164D    "\
          "\n     .word    0x01F601A5    "\
          "\n     .word    0xD74DD7A1    "\
          "\n     .word    0xA361A314    "\
          "\n     .word    0x49CE4934    "\
          "\n     .word    0x8D7B8DDF    "\
          "\n     .word    0x423E429F    "\
          "\n     .word    0x937193CD    "\
          "\n     .word    0xA297A2B1    "\
          "\n     .word    0x04F504A2    "\
          "\n     .word    0xB868B801    "\
          "\n     .word    0x00000000    "\
          "\n     .word    0x742C74B5    "\
          "\n     .word    0xA060A0E0    "\
          "\n     .word    0x211F21C2    "\
          "\n     .word    0x43C8433A    "\
          "\n     .word    0x2CED2C9A    "\
          "\n     .word    0xD9BED90D    "\
          "\n     .word    0xCA46CA47    "\
          "\n     .word    0x70D97017    "\
          "\n     .word    0xDD4BDDAF    "\
          "\n     .word    0x79DE79ED    "\
          "\n     .word    0x67D467FF    "\
          "\n     .word    0x23E82393    "\
          "\n     .word    0xDE4ADE5B    "\
          "\n     .word    0xBD6BBD06    "\
          "\n     .word    0x7E2A7EBB    "\
          "\n     .word    0x34E5347B    "\
          "\n     .word    0x3A163AD7    "\
          "\n     .word    0x54C554D2    "\
          "\n     .word    0x62D762F8    "\
          "\n     .word    0xFF55FF99    "\
          "\n     .word    0xA794A7B6    "\
          "\n     .word    0x4ACF4AC0    "\
          "\n     .word    0x301030D9    "\
          "\n     .word    0x0A060A0E    "\
          "\n     .word    0x98819866    "\
          "\n     .word    0x0BF00BAB    "\
          "\n     .word    0xCC44CCB4    "\
          "\n     .word    0xD5BAD5F0    "\
          "\n     .word    0x3EE33E75    "\
          "\n     .word    0x0EF30EAC    "\
          "\n     .word    0x19FE1944    "\
          "\n     .word    0x5BC05BDB    "\
          "\n     .word    0x858A8580    "\
          "\n     .word    0xECADECD3    "\
          "\n     .word    0xDFBCDFFE    "\
          "\n     .word    0xD848D8A8    "\
          "\n     .word    0x0C040CFD    "\
          "\n     .word    0x7ADF7A19    "\
          "\n     .word    0x58C1582F    "\
          "\n     .word    0x9F759F30    "\
          "\n     .word    0xA563A5E7    "\
          "\n     .word    0x50305070    "\
          "\n     .word    0x2E1A2ECB    "\
          "\n     .word    0x120E12EF    "\
          "\n     .word    0xB76DB708    "\
          "\n     .word    0xD44CD455    "\
          "\n     .word    0x3C143C24    "\
          "\n     .word    0x5F355F79    "\
          "\n     .word    0x712F71B2    "\
          "\n     .word    0x38E13886    "\
          "\n     .word    0xFDA2FDC8    "\
          "\n     .word    0x4FCC4FC7    "\
          "\n     .word    0x4B394B65    "\
          "\n     .word    0xF957F96A    "\
          "\n     .word    0x0DF20D58    "\
          "\n     .word    0x9D829D61    "\
          "\n     .word    0xC947C9B3    "\
          "\n     .word    0xEFACEF27    "\
          "\n     .word    0x32E73288    "\
          "\n     .word    0x7D2B7D4F    "\
          "\n     .word    0xA495A442    "\
          "\n     .word    0xFBA0FB3B    "\
          "\n     .word    0xB398B3AA    "\
          "\n     .word    0x68D168F6    "\
          "\n     .word    0x817F8122    "\
          "\n     .word    0xAA66AAEE    "\
          "\n     .word    0x827E82D6    "\
          "\n     .word    0xE6ABE6DD    "\
          "\n     .word    0x9E839E95    "\
          "\n     .word    0x45CA45C9    "\
          "\n     .word    0x7B297BBC    "\
          "\n     .word    0x6ED36E05    "\
          "\n     .word    0x443C446C    "\
          "\n     .word    0x8B798B2C    "\
          "\n     .word    0x3DE23D81    "\
          "\n     .word    0x271D2731    "\
          "\n     .word    0x9A769A37    "\
          "\n     .word    0x4D3B4D96    "\
          "\n     .word    0xFA56FA9E    "\
          "\n     .word    0xD24ED2A6    "\
          "\n     .word    0x221E2236    "\
          "\n     .word    0x76DB76E4    "\
          "\n     .word    0x1E0A1E12    "\
          "\n     .word    0xB46CB4FC    "\
          "\n     .word    0x37E4378F    "\
          "\n     .word    0xE75DE778    "\
          "\n     .word    0xB26EB20F    "\
          "\n     .word    0x2AEF2A69    "\
          "\n     .word    0xF1A6F135    "\
          "\n     .word    0xE3A8E3DA    "\
          "\n     .word    0xF7A4F7C6    "\
          "\n     .word    0x5937598A    "\
          "\n     .word    0x868B8674    "\
          "\n     .word    0x56325683    "\
          "\n     .word    0xC543C54E    "\
          "\n     .word    0xEB59EB85    "\
          "\n     .word    0xC2B7C218    "\
          "\n     .word    0x8F8C8F8E    "\
          "\n     .word    0xAC64AC1D    "\
          "\n     .word    0x6DD26DF1    "\
          "\n     .word    0x3BE03B72    "\
          "\n     .word    0xC7B4C71F    "\
          "\n     .word    0x15FA15B9    "\
          "\n     .word    0x090709FA    "\
          "\n     .word    0x6F256FA0    "\
          "\n     .word    0xEAAFEA20    "\
          "\n     .word    0x898E897D    "\
          "\n     .word    0x20E92067    "\
          "\n     .word    0x28182838    "\
          "\n     .word    0x64D5640B    "\
          "\n     .word    0x83888373    "\
          "\n     .word    0xB16FB1FB    "\
          "\n     .word    0x967296CA    "\
          "\n     .word    0x6C246C54    "\
          "\n     .word    0x08F1085F    "\
          "\n     .word    0x52C75221    "\
          "\n     .word    0xF351F364    "\
          "\n     .word    0x652365AE    "\
          "\n     .word    0x847C8425    "\
          "\n     .word    0xBF9CBF57    "\
          "\n     .word    0x6321635D    "\
          "\n     .word    0x7CDD7CEA    "\
          "\n     .word    0x7FDC7F1E    "\
          "\n     .word    0x9186919C    "\
          "\n     .word    0x9485949B    "\
          "\n     .word    0xAB90AB4B    "\
          "\n     .word    0xC642C6BA    "\
          "\n     .word    0x57C45726    "\
          "\n     .word    0xE5AAE529    "\
          "\n     .word    0x73D873E3    "\
          "\n     .word    0x0F050F09    "\
          "\n     .word    0x030103F4    "\
          "\n     .word    0x3612362A    "\
          "\n     .word    0xFEA3FE3C    "\
          "\n     .word    0xE15FE18B    "\
          "\n     .word    0x10F910BE    "\
          "\n     .word    0x6BD06B02    "\
          "\n     .word    0xA891A8BF    "\
          "\n     .word    0xE858E871    "\
          "\n     .word    0x69276953    "\
          "\n     .word    0xD0B9D0F7    "\
          "\n     .word    0x48384891    "\
          "\n     .word    0x351335DE    "\
          "\n     .word    0xCEB3CEE5    "\
          "\n     .word    0x55335577    "\
          "\n     .word    0xD6BBD604    "\
          "\n     .word    0x90709039    "\
          "\n     .word    0x80898087    "\
          "\n     .word    0xF2A7F2C1    "\
          "\n     .word    0xC1B6C1EC    "\
          "\n     .word    0x6622665A    "\
          "\n     .word    0xAD92ADB8    "\
          "\n     .word    0x602060A9    "\
          "\n     .word    0xDB49DB5C    "\
          "\n     .word    0x1AFF1AB0    "\
          "\n     .word    0x887888D8    "\
          "\n     .word    0x8E7A8E2B    "\
          "\n     .word    0x8A8F8A89    "\
          "\n     .word    0x13F8134A    "\
          "\n     .word    0x9B809B92    "\
          "\n     .word    0x39173923    "\
          "\n     .word    0x75DA7510    "\
          "\n     .word    0x53315384    "\
          "\n     .word    0x51C651D5    "\
          "\n     .word    0xD3B8D303    "\
          "\n     .word    0x5EC35EDC    "\
          "\n     .word    0xCBB0CBE2    "\
          "\n     .word    0x997799C3    "\
          "\n     .word    0x3311332D    "\
          "\n     .word    0x46CB463D    "\
          "\n     .word    0x1FFC1FB7    "\
          "\n     .word    0x61D6610C    "\
          "\n     .word    0x4E3A4E62    "\
          "\n TABLE_END:                 "\
         );                               \
}
